@@ -13,4 +13,8 @@ public class RuliSync {
     public static Map[] smtpQuery(String domain, int options) {
 	return RuliSyncImp.smtpQuery(domain, options);
     }
+
+    public static Map[] httpQuery(String domain, int forcePort, int options) {
+	return RuliSyncImp.httpQuery(domain, forcePort, options);
+    }
 }
