@@ -1,9 +1,9 @@
 #! /usr/bin/perl -w
 #
-# $Id: ruli-sync-srv.pl,v 1.2 2004/03/26 23:15:52 evertonm Exp $
+# $Id: ruli-sync-srv.pl,v 1.3 2004/09/24 19:40:49 evertonm Exp $
 
 use strict;
-use RULI;
+use Net::RULI;
 
 if ($#ARGV != 1) {
     die <<__EOF__;
@@ -15,7 +15,7 @@ __EOF__
 
 my ($service, $domain) = @ARGV;
 
-my $srv_list_ref = RULI::ruli_sync_query($service, $domain, -1, 0);
+my $srv_list_ref = Net::RULI::ruli_sync_query($service, $domain, -1, 0);
 if (!defined($srv_list_ref)) {
     warn "$service.$domain query failed\n";
     exit(1);
