@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: parse_options.c,v 1.2 2004/10/05 23:04:28 evertonm Exp $
+  $Id: parse_options.c,v 1.4 2005/06/28 22:27:02 evertonm Exp $
  */
 
 #include <string.h>
@@ -42,6 +42,8 @@ struct opt_map {
   { "nowalk",   RULI_RES_OPT_SRV_NOWALK },
   { "nofall",   RULI_RES_OPT_SRV_NOFALL },
   { "nosort6",  RULI_RES_OPT_SRV_NOSORT6 },
+  { "rfc3484",  RULI_RES_OPT_SRV_RFC3484 },
+  { "cname",    RULI_RES_OPT_SRV_CNAME },
   { 0, 0 }
 };
 
