@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli-getaddrinfo.c,v 1.6 2004/06/16 17:28:42 evertonm Exp $
+  $Id: ruli-getaddrinfo.c,v 1.8 2005/08/30 13:40:28 evertonm Exp $
  */
 
 
@@ -37,7 +37,7 @@ Boston, MA 02111-1307, USA.
 
 #include <ruli.h>
 
-#include "stdout_srv_list.h"
+#include "parse_options.h"
 
 
 const int INBUFSZ = 1024;
@@ -267,10 +267,12 @@ static void go()
 }
 
 
-int main(int argc, char *argv[]) 
+int main(int argc, const char *argv[]) 
 {
   prog_name = argv[0];
 
+  ruli_getaddrinfo_setoptions(parse_options(argc, argv, 1));
+
   go();
 
   exit(0);
