@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: smtpsearch.c,v 1.2 2004/06/16 17:28:42 evertonm Exp $
+  $Id: smtpsearch.c,v 1.3 2004/06/21 00:22:37 evertonm Exp $
  */
 
 
@@ -36,6 +36,7 @@ Boston, MA 02111-1307, USA.
 
 #include <ruli.h>
 
+#include "parse_options.h"
 #include "stdout_srv_list.h"
 
 
@@ -172,7 +173,7 @@ static void *run_event_loop(oop_source_sys *source_sys)
   return oop_result;
 }
 
-static void do_query(ruli_res_t *res_ctx, const char *domain)
+static void do_query(ruli_res_t *res_ctx, const char *domain, long options)
 {
   srv_qbuf_t *qbuf;
 
@@ -198,7 +199,7 @@ static void do_query(ruli_res_t *res_ctx, const char *domain)
     ruli_search_srv_t *search = ruli_search_smtp_submit(res_ctx,
 							on_search_answer,
 							qbuf,
-							RULI_RES_OPT_SEARCH,
+							options,
 							qbuf->txt_domain);
     if (!search) {
       fprintf(stderr, 
@@ -216,7 +217,7 @@ static void do_query(ruli_res_t *res_ctx, const char *domain)
    */
 }
 
-static void go()
+static void go(long options)
 {
   oop_source_sys    *source_sys;  /* System event source */
   oop_source        *source;      /* Event registration interface */
@@ -283,7 +284,7 @@ static void go()
 	/*
 	 * Submit query for token
 	 */
-	do_query(res, tok);
+	do_query(res, tok, options);
 	
 	tok = strtok_r(0, SEP, &ptr);
 	if (!tok)
@@ -315,16 +316,12 @@ static void go()
 
 int main(int argc, const char **argv) 
 {
+  long options;
   prog_name = argv[0];
 
-  if (argc != 1) {
-    fprintf(stderr, 
-	    "usage: %s\n", 
-	    prog_name);
-    exit(1);
-  }
+  options = parse_options(argc, argv, 1);
 
-  go();
+  go(options);
 
   exit(0);
 }
