@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: stdout_srv_list.c,v 1.4 2004/05/21 18:23:50 evertonm Exp $
+  $Id: stdout_srv_list.c,v 1.7 2004/05/28 22:17:03 evertonm Exp $
  */
 
 
@@ -89,9 +89,19 @@ void show_srv_list(const char *fullname, const ruli_list_t *srv_list)
      */
 
     for (j = 0; j < addr_list_size; ++j) {
-      struct in_addr *addr = (struct in_addr *) ruli_list_get(addr_list, j);
-
-      printf("%s ", inet_ntoa(*addr));
+      ruli_addr_t *addr = (ruli_addr_t *) ruli_list_get(addr_list, j);
+      switch (ruli_addr_family(addr)) {
+      case PF_INET:
+	printf("IPv4/");
+	break;
+      case PF_INET6:
+	printf("IPv6/");
+	break;
+      default:
+	printf("?/");
+      }
+      ruli_addr_print(stdout, addr);
+      printf(" ");
     }
 
     printf("\n");
