@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: sync_srvsearch.c,v 1.2 2004/06/03 16:54:49 evertonm Exp $
+  $Id: sync_srvsearch.c,v 1.3 2004/06/21 00:22:37 evertonm Exp $
  */
 
 
@@ -32,6 +32,7 @@ Boston, MA 02111-1307, USA.
 
 #include <ruli.h>
 
+#include "parse_options.h"
 #include "stdout_srv_list.h"
 
 
@@ -40,7 +41,7 @@ const int INBUFSZ = 1024;
 const char *prog_name;
 
 
-static void solve(const char *fullname)
+static void solve(const char *fullname, long options)
 {
   int  name_len = strlen(fullname);
   char name[name_len + 1];
@@ -107,7 +108,7 @@ static void solve(const char *fullname)
    */
   {
     ruli_sync_t *sync_query = ruli_sync_query(txt_service, txt_domain, 
-					      -1, RULI_RES_OPT_SEARCH);
+					      -1, options);
     int         srv_code;
 
     /*
@@ -163,7 +164,7 @@ static void solve(const char *fullname)
   }
 }
 
-static void go()
+static void go(long options)
 {
   char inbuf[INBUFSZ];
 
@@ -199,7 +200,7 @@ static void go()
 	/*
 	 * Make SRV query for token
 	 */
-	solve(tok);
+	solve(tok, options);
 
 	tok = strtok_r(0, SEP, &ptr);
 	if (!tok)
@@ -212,11 +213,14 @@ static void go()
 }
 
 
-int main(int argc, char *argv[]) 
+int main(int argc, const char *argv[]) 
 {
+  long options;
   prog_name = argv[0];
 
-  go();
+  options = parse_options(argc, argv, 1);
+
+  go(options);
 
   exit(0);
 }
