@@ -16,7 +16,7 @@
  */
 
 /*
-  $Id: ruli_getaddrinfo.c,v 1.13 2005/06/06 22:57:02 evertonm Exp $
+  $Id: ruli_getaddrinfo.c,v 1.15 2005/08/31 10:43:17 evertonm Exp $
 */
 
 
@@ -41,7 +41,6 @@
 #include <netdb.h>
 #include <stdio.h>
 #include <string.h>
-#include <dlfcn.h>
 
 #include <ruli_getaddrinfo.h>
 #include <ruli_sync.h>
@@ -57,27 +56,18 @@ typedef struct {
   } sa;
 } _ruli_ai_addrbag;
 
-typedef int (*getaddrinfo_call)(const char *node, const char *service,
-	const struct addrinfo *hints,
-	struct addrinfo **res);
+
+static long _ruli_getaddrinfo_options = RULI_RES_OPT_SEARCH | RULI_RES_OPT_SRV_RFC3484;
 
 
-getaddrinfo_call real_getaddrinfo = NULL;
-
-
-static int call_getaddrinfo(const char *node, const char *service,
-			    const struct addrinfo *hints,
-			    struct addrinfo **_res)
+long ruli_getaddrinfo_getoptions(void)
 {
-  if (!real_getaddrinfo)
-    real_getaddrinfo = (getaddrinfo_call) dlsym(RTLD_NEXT, "getaddrinfo");
+  return _ruli_getaddrinfo_options;
+}
 
-  if (!real_getaddrinfo) {
-    errno = ENOTSUP;
-    return EAI_SYSTEM;
-  }
-
-  return real_getaddrinfo(node, service, hints, _res);
+void ruli_getaddrinfo_setoptions(long options)
+{
+  _ruli_getaddrinfo_options = options;
 }
 
 int ruli_getaddrinfo(const char *node, const char *service,
@@ -88,26 +78,26 @@ int ruli_getaddrinfo(const char *node, const char *service,
   struct addrinfo *res = NULL, *res0 = NULL, *res1 = NULL;
   char full_service[RULI_LIMIT_DNAME_TEXT_BUFSZ];
   int srv_code, srv_list_size, i;
-  long options = RULI_RES_OPT_SEARCH | RULI_RES_OPT_SRV_RFC3484;
+  long options = ruli_getaddrinfo_getoptions();
 
   if (!node || (node && !*node) ||
       !service || (service && !*service) || !hints || !_res)
-    return call_getaddrinfo(node, service, hints, _res);
+    return getaddrinfo(node, service, hints, _res);
 
   /* Can't SRV records for numeric hosts. */
   if (hints->ai_flags & AI_NUMERICHOST)
-    return call_getaddrinfo(node, service, hints, _res);
+    return getaddrinfo(node, service, hints, _res);
 	
   /* No numeric services either. */
   if (atoi(service) > 0 || *service == '0')
-    return call_getaddrinfo(node, service, hints, _res);
+    return getaddrinfo(node, service, hints, _res);
 	
   if (hints->ai_socktype == SOCK_STREAM)
     snprintf(full_service, RULI_LIMIT_DNAME_TEXT_BUFSZ, "_%s._tcp", service);
   else if (hints->ai_socktype == SOCK_DGRAM)
     snprintf(full_service, RULI_LIMIT_DNAME_TEXT_BUFSZ, "_%s._udp", service);
   else
-    return call_getaddrinfo(node, service, hints, _res);
+    return getaddrinfo(node, service, hints, _res);
 
   if (hints->ai_family == AF_INET)
     options |= RULI_RES_OPT_SRV_NOINET6;
@@ -116,19 +106,19 @@ int ruli_getaddrinfo(const char *node, const char *service,
 	
   query = ruli_sync_query(full_service, node, -1, options);
   if (!query)
-    return call_getaddrinfo(node, service, hints, _res);
+    return getaddrinfo(node, service, hints, _res);
 
   srv_code = ruli_sync_srv_code(query);
   if (srv_code) {
     ruli_sync_delete(query);
-    return call_getaddrinfo(node, service, hints, _res);
+    return getaddrinfo(node, service, hints, _res);
   }
 
   srv_list = ruli_sync_srv_list(query);
   srv_list_size = ruli_list_size(srv_list);
   if (srv_list_size < 1) {
     ruli_sync_delete(query);
-    return call_getaddrinfo(node, service, hints, _res);
+    return getaddrinfo(node, service, hints, _res);
   }
 
   /* scan srv list */
@@ -263,14 +253,7 @@ int ruli_getaddrinfo(const char *node, const char *service,
 
   /* Something went wrong and res0 isn't populated. */
   if (!res0)
-    return call_getaddrinfo(node, service, hints, _res);
-
-#if 0
-  /* Get the normal getaddrinfo() results if possible and put them at
-     the end of the linked list.*/
-  if (!call_getaddrinfo(node, service, hints, &res1))
-    res->ai_next = res1;
-#endif
+    return getaddrinfo(node, service, hints, _res);
 
   *_res = res0;
   return 0;
