@@ -19,14 +19,13 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /* 
-   $Id: ruli_mem.c,v 1.5 2003/05/03 04:28:17 evertonm Exp $
+   $Id: ruli_mem.c,v 1.6 2004/06/16 17:28:43 evertonm Exp $
    */
 
 
 #include <stdio.h>     /* FIXME: remove me [used for fprintf() debug] */
 
-#include <oop.h>
-
+#include <ruli_oop.h>
 #include <ruli_mem.h>
 
 
