@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_parse.c,v 1.19 2004/06/16 21:23:11 evertonm Exp $
+  $Id: ruli_parse.c,v 1.20 2005/06/07 22:17:51 evertonm Exp $
   */
 
 
@@ -499,8 +499,7 @@ void ruli_parse_addr_rr(ruli_addr_t *addr, const ruli_rr_t *rr, long options)
 				   rr->rdata, rr->rdlength);
       assert(!result); /* IN A parsing can't fail */
     }
-    addr->addr_family = PF_INET;
-    addr->addr_size = sizeof(addr->addr.ipv4);
+    ruli_addr_init(addr, PF_INET);
     break;
     
   case RULI_RR_TYPE_AAAA:
@@ -509,8 +508,7 @@ void ruli_parse_addr_rr(ruli_addr_t *addr, const ruli_rr_t *rr, long options)
 				      rr->rdata, rr->rdlength);
       assert(!result); /* IN AAAA parsing can't fail */
     }
-    addr->addr_family = PF_INET6;
-    addr->addr_size = sizeof(addr->addr.ipv6);
+    ruli_addr_init(addr, PF_INET6);
     break;
     
   default:
