@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_res.h,v 1.26 2005/06/06 22:57:02 evertonm Exp $
+  $Id: ruli_res.h,v 1.27 2005/06/28 22:27:02 evertonm Exp $
   */
 
 
@@ -125,8 +125,9 @@ enum {
   RULI_RES_OPT_SRV_NOWALK   = 1 << 5, /* Don't search missing addresses */
   RULI_RES_OPT_SRV_NOFALL   = 1 << 6, /* Don't launch fallback queries */
   RULI_RES_OPT_SRV_NOSORT6  = 1 << 7, /* Don't sort favorably to v6 addrs */
-  RULI_RES_OPT_SRV_RFC3484  = 1 << 8  /* Apply RFC3484 destination address
+  RULI_RES_OPT_SRV_RFC3484  = 1 << 8, /* Apply RFC3484 destination address
                                          selection rules */
+  RULI_RES_OPT_SRV_CNAME    = 1 << 9  /* Allow CNAME in SRV targets */
 };
 
 typedef struct {
