@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_smtp.h,v 1.1 2003/02/15 09:11:38 evertonm Exp $
+  $Id: ruli_smtp.h,v 1.2 2004/06/21 00:22:48 evertonm Exp $
   */
 
 
@@ -31,7 +31,9 @@ Boston, MA 02111-1307, USA.
 
 
 ruli_search_srv_t *ruli_search_smtp_submit(ruli_res_t *resolver, 
-					   void *(*call)(ruli_search_srv_t *search, void *arg),
+					   void *(*call)
+					   (ruli_search_srv_t *search, 
+					    void *arg),
 					   void *call_arg,
 					   long options,
 					   const char *txt_domain);
