@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_sock.c,v 1.13 2004/09/11 00:39:03 evertonm Exp $
+  $Id: ruli_sock.c,v 1.14 2005/06/08 22:38:28 evertonm Exp $
   */
 
 
@@ -187,22 +187,22 @@ int ruli_sock_has_connected(int tcp_sd)
   - *sa must be large enough to hold either PF_INET or PF_INET6
   - *sa_len is IN for *sa size and OUT for *addr size
  */
-static void ruli_sock_set_address(char *sa, int *sa_len, 
-                                  const ruli_addr_t *addr, int port)
+void ruli_sock_set_sockaddr(struct sockaddr *sa, int *sa_len, 
+			    const _ruli_addr *inet, int family,
+			    int port)
 {
   assert(sa_len);
 
-  switch (addr->addr_family) {
-
+  switch (family) {
   case PF_INET:
     {
       struct sockaddr_in *ad = (struct sockaddr_in *) sa;
 
       assert(*sa_len >= sizeof(*ad));
 
-      ad->sin_family = addr->addr_family;
+      ad->sin_family = family;
       ad->sin_port   = htons(port);
-      ad->sin_addr   = addr->addr.ipv4;
+      ad->sin_addr   = inet->ipv4;
       memset((char *) ad->sin_zero, 0, sizeof(ad->sin_zero));
 
       *sa_len = sizeof(*ad);
@@ -218,16 +218,15 @@ static void ruli_sock_set_address(char *sa, int *sa_len,
       *sa_len = sizeof(*ad);
       memset(ad, 0, *sa_len);
 
-      ad->sin6_family = addr->addr_family;
+      ad->sin6_family = family;
       ad->sin6_port   = htons(port);
-      ad->sin6_addr   = addr->addr.ipv6;
+      ad->sin6_addr   = inet->ipv6;
     }
     break;
     
   default:
     assert(0);
   }
-
 }
 
 int ruli_sock_connect(int sd, const ruli_addr_t *remote_addr, int remote_port)
@@ -241,8 +240,9 @@ int ruli_sock_connect(int sd, const ruli_addr_t *remote_addr, int remote_port)
 
   assert(sizeof(sa) > sizeof(struct sockaddr));
 
-  ruli_sock_set_address((char *) &sa, &sa_len,
-			remote_addr, remote_port);
+  ruli_sock_set_sockaddr((struct sockaddr *) &sa, &sa_len,
+			 &remote_addr->addr, remote_addr->addr_family,
+			 remote_port);
 
   assert((size_t) sa_len >= sizeof(sa.inet));
   assert((size_t) sa_len <= sizeof(sa.inet6));
@@ -274,7 +274,9 @@ int ruli_sock_sendto(int sd, const ruli_addr_t *rem_addr, int rem_port,
 
   assert(sizeof(sa) > sizeof(struct sockaddr));
 
-  ruli_sock_set_address((char *) &sa, &sa_len, rem_addr, rem_port);
+  ruli_sock_set_sockaddr((struct sockaddr *) &sa, &sa_len,
+			 &rem_addr->addr, rem_addr->addr_family,
+			 rem_port);
 
   assert((size_t) sa_len >= sizeof(sa.inet));
   assert((size_t) sa_len <= sizeof(sa.inet6));
