@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_srv.c,v 1.85 2005/06/16 16:55:38 evertonm Exp $
+  $Id: ruli_srv.c,v 1.86 2005/06/28 22:27:02 evertonm Exp $
   */
 
 
@@ -332,7 +332,9 @@ void *_ruli_srv_answer_walk(ruli_srv_t *srv_qry)
     walk_qry->walk_query.host_domain_len      = entry->target_len;
     walk_qry->walk_query.host_options         = srv_qry->srv_options;
     /* RFC 2782 states CNAME aren't valid SRV targets */
-    walk_qry->walk_query.host_max_cname_depth = 0;
+    walk_qry->walk_query.host_max_cname_depth =
+	(srv_qry->srv_options & RULI_RES_OPT_SRV_CNAME) ?
+	RULI_LIMIT_CNAME_DEPTH : 0;
 
     /*
      * Submit walk query
