@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_srv.h,v 1.35 2004/06/23 19:47:29 evertonm Exp $
+  $Id: ruli_srv.h,v 1.38 2004/06/25 23:19:11 evertonm Exp $
   */
 
 
@@ -31,6 +31,7 @@ Boston, MA 02111-1307, USA.
 
 #include <ruli_res.h>
 #include <ruli_parse.h>
+#include <ruli_host.h>
 
 
 /* Return codes for ruli_srv_query_submit() */
@@ -111,14 +112,12 @@ struct ruli_srv_t {
   ruli_list_t      wei_srv_list;   /* random weight ordered list of
 				      *ruli_srv_rdata_t (only references) */
 
-  int              walk_index;     /* index for answer_srv_list */
-  ruli_res_query_t *walk_query;    /* auxiliary query context for "walk" */
-  int              walk_qtype;     /* current walk qtype (IN_A, IN_AAAA) */
-  int              w_query_rcode;  /* rcode for walk query */
+  /* auxiliary context for underlying queries */
+  union {
+    int            walk_index;     /* index for answer_srv_list */
+  } under;
 
-  ruli_res_query_t *fall_query;    /* auxiliary query context for fallback */
-  int              fall_qtype;     /* current fall qtype (IN_A, IN_AAAA) */
-  int              f_query_rcode;  /* rcode for fall query */
+  int              last_rcode;     /* saved rcode for underlying query */
 
   void *(*fallback)(ruli_srv_t *self); /* fallback function */
 
