@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_util.c,v 1.2 2003/01/24 14:39:05 evertonm Exp $
+  $Id: ruli_util.c,v 1.4 2004/06/16 21:53:30 evertonm Exp $
   */
 
 
@@ -56,3 +56,15 @@ ruli_uint32_t ruli_pack4(const ruli_uint8_t *i)
   return a | b | c | d;
 }
 
+void *ruli_memrchr(const void *buf, int c, size_t size)
+{
+  unsigned char wanted = c;
+  const unsigned char *begin = (const unsigned char *) buf;
+  const unsigned char *i;
+
+  for (i = begin + size - 1; i >= begin; --i)
+    if (*i == wanted)
+      return (void *) i;
+
+  return 0;
+}
