@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_util.h,v 1.5 2004/08/25 19:04:23 evertonm Exp $
+  $Id: ruli_util.h,v 1.6 2005/12/07 21:16:18 evertonm Exp $
   */
 
 
@@ -38,15 +38,6 @@ Boston, MA 02111-1307, USA.
 #define RULI_MIN(a, b) (((a) < (b)) ? (a) : (b))
 #endif
 
-#ifndef LONG_MAX
-#define LONG_MAX ( (long) ((((unsigned long) -1L) - 1) >> 1) )
-#endif
-
-#ifndef LONG_MIN
-#define LONG_MIN ( -(LONG_MAX + 1) )
-#endif
-
-
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
