@@ -22,7 +22,7 @@ Boston, MA 02111-1307, USA.
   This test program can redo one query N times.
   One query is resent only after the previous instance is finished.
 
-  $Id: resolve.c,v 1.9 2004/05/31 05:57:41 evertonm Exp $
+  $Id: resolve.c,v 1.10 2004/06/16 17:28:45 evertonm Exp $
  */
 
 
@@ -112,15 +112,15 @@ static void *on_answer(ruli_res_query_t *res_qry, void *arg)
 static void submit_query(ruli_res_t *res_ctx, ruli_res_query_t *res_qry,
 			 const char *domain, int domain_len,
 			 char *dname_buf, int dname_buf_len,
-			 const char *class, const char *type)
+			 const char *qclass, const char *type)
 {
   int  qc, qt;
   int  result;
   char *i;
 
-  qc = ruli_get_qclass_code(class);
+  qc = ruli_get_qclass_code(qclass);
   if (!qc) {
-    fprintf(stderr, "%s: can't find query class: %s\n", prog_name, class);
+    fprintf(stderr, "%s: can't find query class: %s\n", prog_name, qclass);
     exit(1);
   }
 
@@ -153,7 +153,7 @@ static void submit_query(ruli_res_t *res_ctx, ruli_res_query_t *res_qry,
   }
 }
 
-static void perform_query(const char *domain, const char *class, 
+static void perform_query(const char *domain, const char *qclass, 
 			  const char *type, int retry, int timeout,
 			  ruli_list_t *server_list)
 {
@@ -203,7 +203,7 @@ static void perform_query(const char *domain, const char *class,
    */
   submit_query(&res_ctx, &res_qry, domain, domain_len,
 	       dname_buf, dname_buf_len,
-	       class, type);
+	       qclass, type);
 
   /*
    * Replay
@@ -211,7 +211,7 @@ static void perform_query(const char *domain, const char *class,
   /*
   submit_query(&res_ctx, &res_qry2, domain, domain_len,
 	       dname_buf, dname_buf_len,
-	       class, type);
+	       qclass, type);
   */
 
   /*
@@ -272,7 +272,7 @@ static void parse_servers(ruli_list_t *server_list, int serverc,
 int main(int argc, const char **argv) 
 {
   const char  *domain;
-  const char  *class;
+  const char  *qclass;
   const char  *type;
   int         retry;
   int         timeout;
@@ -291,7 +291,7 @@ int main(int argc, const char **argv)
 
   redo    = atoi(argv[1]);
   domain  = argv[2];
-  class   = argv[3];
+  qclass   = argv[3];
   type    = argv[4];
   retry   = atoi(argv[5]);
   timeout = atoi(argv[6]);
@@ -320,7 +320,7 @@ int main(int argc, const char **argv)
 
   parse_servers(&server_list, serverc, serverv);
 
-  perform_query(domain, class, type, retry, timeout, &server_list);
+  perform_query(domain, qclass, type, retry, timeout, &server_list);
 
   ruli_list_dispose_trivial(&server_list);
 
