@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: stdout_srv_list.c,v 1.10 2004/05/28 01:16:49 evertonm Exp $
+  $Id: stdout_srv_list.c,v 1.11 2004/06/16 17:28:45 evertonm Exp $
  */
 
 
@@ -48,7 +48,7 @@ void show_srv_list(const char *fullname, const ruli_list_t *srv_list)
    * Scan list of SRV records
    */
   for (i = 0; i < srv_list_size; ++i) {
-    ruli_srv_entry_t *entry         = ruli_list_get(srv_list, i);
+    ruli_srv_entry_t *entry         = (ruli_srv_entry_t *) ruli_list_get(srv_list, i);
     ruli_list_t      *addr_list     = &entry->addr_list;
     int              addr_list_size = ruli_list_size(addr_list);
     int              j;
